library(ggplot2) 
library(lme4)
library(multcomp)
#setwd("/Users/carlykenkel/Desktop/Carly'sAdaptationExpt/RNAseq/qpcrValidation") # specify the path to your data here
o=read.csv("ShortTermCandidates.csv")
n=read.csv("LongTermCandidates.csv")
head(o)
head(n)
o$tank=as.factor(o$tank)
n$tank=as.factor(n$tank)


#######################Statistical Analyses
qpcr=n #explore both the o and n datasets by changing this variable

gene="PEPCK" #change gene name to reflect gene that you want to query within the appropriate dataset
sub=qpcr[,gene]

tank=lmer(sub~(1|sample)+(1|tank),qpcr) # evaluate effect of tank
null=lmer(sub~(1|sample),qpcr)
anova(null,tank)

###Tank effect significance
#[o]  "abcryst 0.06078"    "actin 0.8532"     "adk 0.7867"       "c3 1"        "chrom 1"     "hsp60 0.2001"     "hsp90 0.0533"     "spon2 1"     "ubl3 0.4914"      
#[n]"AdaGAT 1"    "ALP 0.1138"       "Cal4 0.1803"      "Col 1"         "Exoc4 0.5544"     "MalSyn 1"      "PyrCA 0.003318"       "SCF 3.873e-05"    "PEPCK 0.2107"     "ACAD 1" 
#"PaleDblGene 0.3954"

#####fixed factor models
###with tank effects if significant above
full=lmer(sub~origin+status50_50+origin:status50_50+(1|sample)+(1|tank),qpcr)
i=lmer(sub~status50_50+origin+(1|sample)+(1|tank),qpcr)
treat=lmer(sub~status50_50+(1|sample)+(1|tank),qpcr)
ori=lmer(sub~origin+(1|sample)+(1|tank),qpcr)

anova(tank,ori) #origin effects
anova(tank,treat) #treatment effects
anova(i,full) #interaction term

###no tank effects if not significant above
full=lmer(sub~origin+treatment+origin:treatment+(1|sample),qpcr)
i=lmer(sub~treatment+origin+(1|sample),qpcr)
treat=lmer(sub~treatment+(1|sample),qpcr)
ori=lmer(sub~origin+(1|sample),qpcr)

anova(null,ori) #origin effects
anova(null,treat) #treatment effects
anova(i,full) #interaction term

f=lmer(sub~origin+status50_50+origin:status50_50+(1|sample),qpcr)
int=lmer(sub~status50_50+origin+(1|sample),qpcr)
trt=lmer(sub~status50_50+(1|sample),qpcr)
o=lmer(sub~origin+(1|sample),qpcr)

anova(null,o) #origin effects
anova(null,trt) #treatment effects
anova(int,f) #interaction term

#Gene order within each dataset
#[o]  "abcryst"   "actin"     "adk"       "c3"        "chrom"     "hsp60"     "hsp90"     "spon2"     "ubl3"      
#[n]"AdaGAT"    "ALP"       "Cal4"      "Col"       "Exoc4"     "MalSyn"    "PyrCA"      "SCF"    "PEPCK"     "ACAD"
#Pale dbl gene: trt 0.008597

#########FDR correction for all genes in order listed above - origin * bleaching status
p.adjust(c(0.5703,0.1021,0.4644,0.06698,0.05584,0.1178,0.2132,0.07306,0.3099,     0.02971,0.08027,0.6951,0.01006,0.6678,0.5717,0.006378,0.5119,0.02363,0.0008063),method="BH") #origin
p.adjust(c(0.4092,0.1579,0.002624,0.06872,0.5382,0.3652,6.561e-06,0.5025,0.0847,  0.06857,0.04354,0.01378,0.235,0.1015,0.2805,0.225,5.348e-06,0.01124,0.6609),method="BH")  #status 
p.adjust(c(0.4764,0.1391,0.1851, 0.3486,0.3064,0.1864,0.4466,0.7216,0.8924,       0.6162,0.4717,0.2513,0.2147,0.4436,0.9515,0.8953,0.5356,0.6888,0.1993),method="BH")  #interaction


#########FDR correction for all genes in order listed above - origin * treatment
p.adjust(c(0.5703,4.909e-13,9.088e-08,0.06698,0.05584,0.1178,0.2132,0.07306,0.3099,     0.02971,0.08027,0.6951,0.01006,0.6678,0.5717,0.006378,0.5119,0.02363,0.0008063),method="BH") #origin
p.adjust(c(0.1855,1.247e-12,2.704e-10,0.06872,0.5382,0.3652,6.561e-06,0.5025,0.0847,  0.06857,0.04354,0.01378,0.235,0.1015,0.2805,0.225,5.348e-06,0.01124,0.6609),method="BH")  #Treatment 
p.adjust(c(0.8669,0.2872,0.3316, 0.3486,0.3064,0.1864,0.4466,0.7216,0.8924,       0.6162,0.4717,0.2513,0.2147,0.4436,0.9515,0.8953,0.5356,0.6888,0.1993),method="BH")  #interaction


##Tukey multiple comparisson for status50_50 model if significant following FDR
#genes:  
qpcr=n
gene="PEPCK"
sub=qpcr[,gene]
treat=lmer(sub~status50_50+(1|sample),qpcr)
treat=lmer(sub~status50_50+(1|sample)+(1|tank),qpcr)

summary(glht(treat,linfct = mcp (status50_50 = "Tukey")))


##################Rearrange for plotting
# stacking olds
conds=c(1:6)
o.gens=c(7:15)
s.o=stack(o[,o.gens])
names(s.o)=c("expr","gene")
s.o[,3:8]=o[,conds]
s.o$tank=as.factor(s.o$tank)
s.o$status2=as.factor(sub("h.","",s.o$status2))
summary(s.o)

names(n)
names(o)
n=n[,c(2,3,5,1,4,6:23)] # to keep conditions columns in the same order as in olds

n=n[,-c(11,14,16,17,19,22,23)] #removing normalizer and doublegene columns
names(n)

# stacking news
conds=c(1:6)
n.gens=c(7:16)
s.n=stack(n[,n.gens])
names(s.n)=c("expr","gene")
s.n[,3:8]=n[,conds]
head(s.n)
s.n$tank=as.factor(s.n$tank)
s.n$status2=as.factor(sub("h.","",s.n$status2))
summary(s.n)
summary(s.o)

all=rbind(s.o,s.n)
str(all)
all$status50_50=factor(all$status50_50,levels=c("normal","pale","bleach"))


##############Execute SummarySE function to calculate means and stderror for each gene
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
    require(plyr)

    # New version of length which can handle NA's: if na.rm==T, don't count them
    length2 <- function (x, na.rm=FALSE) {
        if (na.rm) sum(!is.na(x))
        else       length(x)
    }

    # This is does the summary; it's not easy to understand...
    datac <- ddply(data, groupvars, .drop=.drop,
                   .fun= function(xx, col, na.rm) {
                           c( N    = length2(xx[,col], na.rm=na.rm),
                              mean = mean   (xx[,col], na.rm=na.rm),
                              sd   = sd     (xx[,col], na.rm=na.rm)
                              )
                          },
                    measurevar,
                    na.rm
             )

    # Rename the "mean" column    
    datac <- rename(datac, c("mean"=measurevar))

    datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean

    # Confidence interval multiplier for standard error
    # Calculate t-statistic for confidence interval: 
    # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
    ciMult <- qt(conf.interval/2 + .5, datac$N-1)
    datac$ci <- datac$se * ciMult

    return(datac)
}


all=all[complete.cases(all),] #removing NA's
all.summ=summarySE(all,measurevar="expr",groupvars=c("gene","origin","status50_50"))
#write.table(all.summ,"marginal_means_qPCR_commongarden_status5050.txt",quote=F, sep="\t")

#color:
pd <- position_dodge(.3)
ggplot(all.summ,aes(x=status50_50,y=expr,colour=origin,group=origin))+
	geom_errorbar(aes(ymin=expr-se,ymax=expr+se),lwd=0.4,width=0.3,position=pd)+
	geom_line(aes(group=origin,linetype=origin),position=pd)+
	geom_point(aes(group=origin,pch=origin),position=pd,size=2.5)+
	facet_wrap(~gene,scales="free_y")+theme_bw()

